# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/tx/v1beta1/service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.abci.v1beta1 import abci_pb2 as cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2
from cosmos.tx.v1beta1 import tx_pb2 as cosmos_dot_tx_dot_v1beta1_dot_tx__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from tendermint.types import block_pb2 as tendermint_dot_types_dot_block__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/tx/v1beta1/service.proto',
  package='cosmos.tx.v1beta1',
  syntax='proto3',
  serialized_options=b'Z%github.com/cosmos/cosmos-sdk/types/tx\300\343\036\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x63osmos/tx/v1beta1/service.proto\x12\x11\x63osmos.tx.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a#cosmos/base/abci/v1beta1/abci.proto\x1a\x1a\x63osmos/tx/v1beta1/tx.proto\x1a\x14gogoproto/gogo.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1ctendermint/types/block.proto\x1a\x1ctendermint/types/types.proto\"\x8e\x01\n\x12GetTxsEventRequest\x12\x0e\n\x06\x65vents\x18\x01 \x03(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x12,\n\x08order_by\x18\x03 \x01(\x0e\x32\x1a.cosmos.tx.v1beta1.OrderBy\"\xb2\x01\n\x13GetTxsEventResponse\x12\"\n\x03txs\x18\x01 \x03(\x0b\x32\x15.cosmos.tx.v1beta1.Tx\x12:\n\x0ctx_responses\x18\x02 \x03(\x0b\x32$.cosmos.base.abci.v1beta1.TxResponse\x12;\n\npagination\x18\x03 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"V\n\x12\x42roadcastTxRequest\x12\x10\n\x08tx_bytes\x18\x01 \x01(\x0c\x12.\n\x04mode\x18\x02 \x01(\x0e\x32 .cosmos.tx.v1beta1.BroadcastMode\"P\n\x13\x42roadcastTxResponse\x12\x39\n\x0btx_response\x18\x01 \x01(\x0b\x32$.cosmos.base.abci.v1beta1.TxResponse\"J\n\x0fSimulateRequest\x12%\n\x02tx\x18\x01 \x01(\x0b\x32\x15.cosmos.tx.v1beta1.TxB\x02\x18\x01\x12\x10\n\x08tx_bytes\x18\x02 \x01(\x0c\"y\n\x10SimulateResponse\x12\x33\n\x08gas_info\x18\x01 \x01(\x0b\x32!.cosmos.base.abci.v1beta1.GasInfo\x12\x30\n\x06result\x18\x02 \x01(\x0b\x32 .cosmos.base.abci.v1beta1.Result\"\x1c\n\x0cGetTxRequest\x12\x0c\n\x04hash\x18\x01 \x01(\t\"m\n\rGetTxResponse\x12!\n\x02tx\x18\x01 \x01(\x0b\x32\x15.cosmos.tx.v1beta1.Tx\x12\x39\n\x0btx_response\x18\x02 \x01(\x0b\x32$.cosmos.base.abci.v1beta1.TxResponse\"d\n\x16GetBlockWithTxsRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xcf\x01\n\x17GetBlockWithTxsResponse\x12\"\n\x03txs\x18\x01 \x03(\x0b\x32\x15.cosmos.tx.v1beta1.Tx\x12+\n\x08\x62lock_id\x18\x02 \x01(\x0b\x32\x19.tendermint.types.BlockID\x12&\n\x05\x62lock\x18\x03 \x01(\x0b\x32\x17.tendermint.types.Block\x12;\n\npagination\x18\x04 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse*H\n\x07OrderBy\x12\x18\n\x14ORDER_BY_UNSPECIFIED\x10\x00\x12\x10\n\x0cORDER_BY_ASC\x10\x01\x12\x11\n\rORDER_BY_DESC\x10\x02*|\n\rBroadcastMode\x12\x1e\n\x1a\x42ROADCAST_MODE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x42ROADCAST_MODE_BLOCK\x10\x01\x12\x17\n\x13\x42ROADCAST_MODE_SYNC\x10\x02\x12\x18\n\x14\x42ROADCAST_MODE_ASYNC\x10\x03\x32\x92\x05\n\x07Service\x12{\n\x08Simulate\x12\".cosmos.tx.v1beta1.SimulateRequest\x1a#.cosmos.tx.v1beta1.SimulateResponse\"&\x82\xd3\xe4\x93\x02 \"\x1b/cosmos/tx/v1beta1/simulate:\x01*\x12q\n\x05GetTx\x12\x1f.cosmos.tx.v1beta1.GetTxRequest\x1a .cosmos.tx.v1beta1.GetTxResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/tx/v1beta1/txs/{hash}\x12\x7f\n\x0b\x42roadcastTx\x12%.cosmos.tx.v1beta1.BroadcastTxRequest\x1a&.cosmos.tx.v1beta1.BroadcastTxResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/cosmos/tx/v1beta1/txs:\x01*\x12|\n\x0bGetTxsEvent\x12%.cosmos.tx.v1beta1.GetTxsEventRequest\x1a&.cosmos.tx.v1beta1.GetTxsEventResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/cosmos/tx/v1beta1/txs\x12\x97\x01\n\x0fGetBlockWithTxs\x12).cosmos.tx.v1beta1.GetBlockWithTxsRequest\x1a*.cosmos.tx.v1beta1.GetBlockWithTxsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/cosmos/tx/v1beta1/txs/block/{height}B+Z%github.com/cosmos/cosmos-sdk/types/tx\xc0\xe3\x1e\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2.DESCRIPTOR,cosmos_dot_tx_dot_v1beta1_dot_tx__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2.DESCRIPTOR,tendermint_dot_types_dot_block__pb2.DESCRIPTOR,tendermint_dot_types_dot_types__pb2.DESCRIPTOR,])

_ORDERBY = _descriptor.EnumDescriptor(
  name='OrderBy',
  full_name='cosmos.tx.v1beta1.OrderBy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ORDER_BY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORDER_BY_ASC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORDER_BY_DESC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1423,
  serialized_end=1495,
)
_sym_db.RegisterEnumDescriptor(_ORDERBY)

OrderBy = enum_type_wrapper.EnumTypeWrapper(_ORDERBY)
_BROADCASTMODE = _descriptor.EnumDescriptor(
  name='BroadcastMode',
  full_name='cosmos.tx.v1beta1.BroadcastMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BROADCAST_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BROADCAST_MODE_BLOCK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BROADCAST_MODE_SYNC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BROADCAST_MODE_ASYNC', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1497,
  serialized_end=1621,
)
_sym_db.RegisterEnumDescriptor(_BROADCASTMODE)

BroadcastMode = enum_type_wrapper.EnumTypeWrapper(_BROADCASTMODE)
ORDER_BY_UNSPECIFIED = 0
ORDER_BY_ASC = 1
ORDER_BY_DESC = 2
BROADCAST_MODE_UNSPECIFIED = 0
BROADCAST_MODE_BLOCK = 1
BROADCAST_MODE_SYNC = 2
BROADCAST_MODE_ASYNC = 3



_GETTXSEVENTREQUEST = _descriptor.Descriptor(
  name='GetTxsEventRequest',
  full_name='cosmos.tx.v1beta1.GetTxsEventRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='cosmos.tx.v1beta1.GetTxsEventRequest.events', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.tx.v1beta1.GetTxsEventRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='cosmos.tx.v1beta1.GetTxsEventRequest.order_by', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=418,
)


_GETTXSEVENTRESPONSE = _descriptor.Descriptor(
  name='GetTxsEventResponse',
  full_name='cosmos.tx.v1beta1.GetTxsEventResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='txs', full_name='cosmos.tx.v1beta1.GetTxsEventResponse.txs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_responses', full_name='cosmos.tx.v1beta1.GetTxsEventResponse.tx_responses', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.tx.v1beta1.GetTxsEventResponse.pagination', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=599,
)


_BROADCASTTXREQUEST = _descriptor.Descriptor(
  name='BroadcastTxRequest',
  full_name='cosmos.tx.v1beta1.BroadcastTxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_bytes', full_name='cosmos.tx.v1beta1.BroadcastTxRequest.tx_bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='cosmos.tx.v1beta1.BroadcastTxRequest.mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=601,
  serialized_end=687,
)


_BROADCASTTXRESPONSE = _descriptor.Descriptor(
  name='BroadcastTxResponse',
  full_name='cosmos.tx.v1beta1.BroadcastTxResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_response', full_name='cosmos.tx.v1beta1.BroadcastTxResponse.tx_response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=689,
  serialized_end=769,
)


_SIMULATEREQUEST = _descriptor.Descriptor(
  name='SimulateRequest',
  full_name='cosmos.tx.v1beta1.SimulateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx', full_name='cosmos.tx.v1beta1.SimulateRequest.tx', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_bytes', full_name='cosmos.tx.v1beta1.SimulateRequest.tx_bytes', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=771,
  serialized_end=845,
)


_SIMULATERESPONSE = _descriptor.Descriptor(
  name='SimulateResponse',
  full_name='cosmos.tx.v1beta1.SimulateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gas_info', full_name='cosmos.tx.v1beta1.SimulateResponse.gas_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='cosmos.tx.v1beta1.SimulateResponse.result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=847,
  serialized_end=968,
)


_GETTXREQUEST = _descriptor.Descriptor(
  name='GetTxRequest',
  full_name='cosmos.tx.v1beta1.GetTxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='cosmos.tx.v1beta1.GetTxRequest.hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=970,
  serialized_end=998,
)


_GETTXRESPONSE = _descriptor.Descriptor(
  name='GetTxResponse',
  full_name='cosmos.tx.v1beta1.GetTxResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx', full_name='cosmos.tx.v1beta1.GetTxResponse.tx', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_response', full_name='cosmos.tx.v1beta1.GetTxResponse.tx_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1000,
  serialized_end=1109,
)


_GETBLOCKWITHTXSREQUEST = _descriptor.Descriptor(
  name='GetBlockWithTxsRequest',
  full_name='cosmos.tx.v1beta1.GetBlockWithTxsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='cosmos.tx.v1beta1.GetBlockWithTxsRequest.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.tx.v1beta1.GetBlockWithTxsRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1111,
  serialized_end=1211,
)


_GETBLOCKWITHTXSRESPONSE = _descriptor.Descriptor(
  name='GetBlockWithTxsResponse',
  full_name='cosmos.tx.v1beta1.GetBlockWithTxsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='txs', full_name='cosmos.tx.v1beta1.GetBlockWithTxsResponse.txs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_id', full_name='cosmos.tx.v1beta1.GetBlockWithTxsResponse.block_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block', full_name='cosmos.tx.v1beta1.GetBlockWithTxsResponse.block', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.tx.v1beta1.GetBlockWithTxsResponse.pagination', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1214,
  serialized_end=1421,
)

_GETTXSEVENTREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_GETTXSEVENTREQUEST.fields_by_name['order_by'].enum_type = _ORDERBY
_GETTXSEVENTRESPONSE.fields_by_name['txs'].message_type = cosmos_dot_tx_dot_v1beta1_dot_tx__pb2._TX
_GETTXSEVENTRESPONSE.fields_by_name['tx_responses'].message_type = cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2._TXRESPONSE
_GETTXSEVENTRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_BROADCASTTXREQUEST.fields_by_name['mode'].enum_type = _BROADCASTMODE
_BROADCASTTXRESPONSE.fields_by_name['tx_response'].message_type = cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2._TXRESPONSE
_SIMULATEREQUEST.fields_by_name['tx'].message_type = cosmos_dot_tx_dot_v1beta1_dot_tx__pb2._TX
_SIMULATERESPONSE.fields_by_name['gas_info'].message_type = cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2._GASINFO
_SIMULATERESPONSE.fields_by_name['result'].message_type = cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2._RESULT
_GETTXRESPONSE.fields_by_name['tx'].message_type = cosmos_dot_tx_dot_v1beta1_dot_tx__pb2._TX
_GETTXRESPONSE.fields_by_name['tx_response'].message_type = cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2._TXRESPONSE
_GETBLOCKWITHTXSREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_GETBLOCKWITHTXSRESPONSE.fields_by_name['txs'].message_type = cosmos_dot_tx_dot_v1beta1_dot_tx__pb2._TX
_GETBLOCKWITHTXSRESPONSE.fields_by_name['block_id'].message_type = tendermint_dot_types_dot_types__pb2._BLOCKID
_GETBLOCKWITHTXSRESPONSE.fields_by_name['block'].message_type = tendermint_dot_types_dot_block__pb2._BLOCK
_GETBLOCKWITHTXSRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
DESCRIPTOR.message_types_by_name['GetTxsEventRequest'] = _GETTXSEVENTREQUEST
DESCRIPTOR.message_types_by_name['GetTxsEventResponse'] = _GETTXSEVENTRESPONSE
DESCRIPTOR.message_types_by_name['BroadcastTxRequest'] = _BROADCASTTXREQUEST
DESCRIPTOR.message_types_by_name['BroadcastTxResponse'] = _BROADCASTTXRESPONSE
DESCRIPTOR.message_types_by_name['SimulateRequest'] = _SIMULATEREQUEST
DESCRIPTOR.message_types_by_name['SimulateResponse'] = _SIMULATERESPONSE
DESCRIPTOR.message_types_by_name['GetTxRequest'] = _GETTXREQUEST
DESCRIPTOR.message_types_by_name['GetTxResponse'] = _GETTXRESPONSE
DESCRIPTOR.message_types_by_name['GetBlockWithTxsRequest'] = _GETBLOCKWITHTXSREQUEST
DESCRIPTOR.message_types_by_name['GetBlockWithTxsResponse'] = _GETBLOCKWITHTXSRESPONSE
DESCRIPTOR.enum_types_by_name['OrderBy'] = _ORDERBY
DESCRIPTOR.enum_types_by_name['BroadcastMode'] = _BROADCASTMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetTxsEventRequest = _reflection.GeneratedProtocolMessageType('GetTxsEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTXSEVENTREQUEST,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetTxsEventRequest)
  })
_sym_db.RegisterMessage(GetTxsEventRequest)

GetTxsEventResponse = _reflection.GeneratedProtocolMessageType('GetTxsEventResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTXSEVENTRESPONSE,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetTxsEventResponse)
  })
_sym_db.RegisterMessage(GetTxsEventResponse)

BroadcastTxRequest = _reflection.GeneratedProtocolMessageType('BroadcastTxRequest', (_message.Message,), {
  'DESCRIPTOR' : _BROADCASTTXREQUEST,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.BroadcastTxRequest)
  })
_sym_db.RegisterMessage(BroadcastTxRequest)

BroadcastTxResponse = _reflection.GeneratedProtocolMessageType('BroadcastTxResponse', (_message.Message,), {
  'DESCRIPTOR' : _BROADCASTTXRESPONSE,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.BroadcastTxResponse)
  })
_sym_db.RegisterMessage(BroadcastTxResponse)

SimulateRequest = _reflection.GeneratedProtocolMessageType('SimulateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATEREQUEST,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.SimulateRequest)
  })
_sym_db.RegisterMessage(SimulateRequest)

SimulateResponse = _reflection.GeneratedProtocolMessageType('SimulateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATERESPONSE,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.SimulateResponse)
  })
_sym_db.RegisterMessage(SimulateResponse)

GetTxRequest = _reflection.GeneratedProtocolMessageType('GetTxRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTXREQUEST,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetTxRequest)
  })
_sym_db.RegisterMessage(GetTxRequest)

GetTxResponse = _reflection.GeneratedProtocolMessageType('GetTxResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTXRESPONSE,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetTxResponse)
  })
_sym_db.RegisterMessage(GetTxResponse)

GetBlockWithTxsRequest = _reflection.GeneratedProtocolMessageType('GetBlockWithTxsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKWITHTXSREQUEST,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetBlockWithTxsRequest)
  })
_sym_db.RegisterMessage(GetBlockWithTxsRequest)

GetBlockWithTxsResponse = _reflection.GeneratedProtocolMessageType('GetBlockWithTxsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKWITHTXSRESPONSE,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetBlockWithTxsResponse)
  })
_sym_db.RegisterMessage(GetBlockWithTxsResponse)


DESCRIPTOR._options = None
_SIMULATEREQUEST.fields_by_name['tx']._options = None

_SERVICE = _descriptor.ServiceDescriptor(
  name='Service',
  full_name='cosmos.tx.v1beta1.Service',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1624,
  serialized_end=2282,
  methods=[
  _descriptor.MethodDescriptor(
    name='Simulate',
    full_name='cosmos.tx.v1beta1.Service.Simulate',
    index=0,
    containing_service=None,
    input_type=_SIMULATEREQUEST,
    output_type=_SIMULATERESPONSE,
    serialized_options=b'\202\323\344\223\002 \"\033/cosmos/tx/v1beta1/simulate:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTx',
    full_name='cosmos.tx.v1beta1.Service.GetTx',
    index=1,
    containing_service=None,
    input_type=_GETTXREQUEST,
    output_type=_GETTXRESPONSE,
    serialized_options=b'\202\323\344\223\002\037\022\035/cosmos/tx/v1beta1/txs/{hash}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BroadcastTx',
    full_name='cosmos.tx.v1beta1.Service.BroadcastTx',
    index=2,
    containing_service=None,
    input_type=_BROADCASTTXREQUEST,
    output_type=_BROADCASTTXRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\"\026/cosmos/tx/v1beta1/txs:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTxsEvent',
    full_name='cosmos.tx.v1beta1.Service.GetTxsEvent',
    index=3,
    containing_service=None,
    input_type=_GETTXSEVENTREQUEST,
    output_type=_GETTXSEVENTRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/cosmos/tx/v1beta1/txs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlockWithTxs',
    full_name='cosmos.tx.v1beta1.Service.GetBlockWithTxs',
    index=4,
    containing_service=None,
    input_type=_GETBLOCKWITHTXSREQUEST,
    output_type=_GETBLOCKWITHTXSRESPONSE,
    serialized_options=b'\202\323\344\223\002\'\022%/cosmos/tx/v1beta1/txs/block/{height}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SERVICE)

DESCRIPTOR.services_by_name['Service'] = _SERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/consensus/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from tendermint.libs.bits import types_pb2 as tendermint_dot_libs_dot_bits_dot_types__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/consensus/types.proto',
  package='tendermint.consensus',
  syntax='proto3',
  serialized_options=b'Z;github.com/tendermint/tendermint/proto/tendermint/consensus',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n tendermint/consensus/types.proto\x12\x14tendermint.consensus\x1a\x14gogoproto/gogo.proto\x1a\x1ctendermint/types/types.proto\x1a tendermint/libs/bits/types.proto\"x\n\x0cNewRoundStep\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12\x0c\n\x04step\x18\x03 \x01(\r\x12 \n\x18seconds_since_start_time\x18\x04 \x01(\x03\x12\x19\n\x11last_commit_round\x18\x05 \x01(\x05\"\xbc\x01\n\rNewValidBlock\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12\x44\n\x15\x62lock_part_set_header\x18\x03 \x01(\x0b\x32\x1f.tendermint.types.PartSetHeaderB\x04\xc8\xde\x1f\x00\x12\x33\n\x0b\x62lock_parts\x18\x04 \x01(\x0b\x32\x1e.tendermint.libs.bits.BitArray\x12\x11\n\tis_commit\x18\x05 \x01(\x08\">\n\x08Proposal\x12\x32\n\x08proposal\x18\x01 \x01(\x0b\x32\x1a.tendermint.types.ProposalB\x04\xc8\xde\x1f\x00\"u\n\x0bProposalPOL\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x1a\n\x12proposal_pol_round\x18\x02 \x01(\x05\x12:\n\x0cproposal_pol\x18\x03 \x01(\x0b\x32\x1e.tendermint.libs.bits.BitArrayB\x04\xc8\xde\x1f\x00\"V\n\tBlockPart\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12*\n\x04part\x18\x03 \x01(\x0b\x32\x16.tendermint.types.PartB\x04\xc8\xde\x1f\x00\",\n\x04Vote\x12$\n\x04vote\x18\x01 \x01(\x0b\x32\x16.tendermint.types.Vote\"f\n\x07HasVote\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12-\n\x04type\x18\x03 \x01(\x0e\x32\x1f.tendermint.types.SignedMsgType\x12\r\n\x05index\x18\x04 \x01(\x05\"\x9a\x01\n\x0cVoteSetMaj23\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12-\n\x04type\x18\x03 \x01(\x0e\x32\x1f.tendermint.types.SignedMsgType\x12<\n\x08\x62lock_id\x18\x04 \x01(\x0b\x32\x19.tendermint.types.BlockIDB\x0f\xe2\xde\x1f\x07\x42lockID\xc8\xde\x1f\x00\"\xce\x01\n\x0bVoteSetBits\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12-\n\x04type\x18\x03 \x01(\x0e\x32\x1f.tendermint.types.SignedMsgType\x12<\n\x08\x62lock_id\x18\x04 \x01(\x0b\x32\x19.tendermint.types.BlockIDB\x0f\xe2\xde\x1f\x07\x42lockID\xc8\xde\x1f\x00\x12\x33\n\x05votes\x18\x05 \x01(\x0b\x32\x1e.tendermint.libs.bits.BitArrayB\x04\xc8\xde\x1f\x00\"\x8d\x04\n\x07Message\x12<\n\x0enew_round_step\x18\x01 \x01(\x0b\x32\".tendermint.consensus.NewRoundStepH\x00\x12>\n\x0fnew_valid_block\x18\x02 \x01(\x0b\x32#.tendermint.consensus.NewValidBlockH\x00\x12\x32\n\x08proposal\x18\x03 \x01(\x0b\x32\x1e.tendermint.consensus.ProposalH\x00\x12\x39\n\x0cproposal_pol\x18\x04 \x01(\x0b\x32!.tendermint.consensus.ProposalPOLH\x00\x12\x35\n\nblock_part\x18\x05 \x01(\x0b\x32\x1f.tendermint.consensus.BlockPartH\x00\x12*\n\x04vote\x18\x06 \x01(\x0b\x32\x1a.tendermint.consensus.VoteH\x00\x12\x31\n\x08has_vote\x18\x07 \x01(\x0b\x32\x1d.tendermint.consensus.HasVoteH\x00\x12<\n\x0evote_set_maj23\x18\x08 \x01(\x0b\x32\".tendermint.consensus.VoteSetMaj23H\x00\x12:\n\rvote_set_bits\x18\t \x01(\x0b\x32!.tendermint.consensus.VoteSetBitsH\x00\x42\x05\n\x03sumB=Z;github.com/tendermint/tendermint/proto/tendermint/consensusb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,tendermint_dot_types_dot_types__pb2.DESCRIPTOR,tendermint_dot_libs_dot_bits_dot_types__pb2.DESCRIPTOR,])




_NEWROUNDSTEP = _descriptor.Descriptor(
  name='NewRoundStep',
  full_name='tendermint.consensus.NewRoundStep',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.consensus.NewRoundStep.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='tendermint.consensus.NewRoundStep.round', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='tendermint.consensus.NewRoundStep.step', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds_since_start_time', full_name='tendermint.consensus.NewRoundStep.seconds_since_start_time', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_commit_round', full_name='tendermint.consensus.NewRoundStep.last_commit_round', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=264,
)


_NEWVALIDBLOCK = _descriptor.Descriptor(
  name='NewValidBlock',
  full_name='tendermint.consensus.NewValidBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.consensus.NewValidBlock.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='tendermint.consensus.NewValidBlock.round', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_part_set_header', full_name='tendermint.consensus.NewValidBlock.block_part_set_header', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_parts', full_name='tendermint.consensus.NewValidBlock.block_parts', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_commit', full_name='tendermint.consensus.NewValidBlock.is_commit', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=267,
  serialized_end=455,
)


_PROPOSAL = _descriptor.Descriptor(
  name='Proposal',
  full_name='tendermint.consensus.Proposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposal', full_name='tendermint.consensus.Proposal.proposal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=457,
  serialized_end=519,
)


_PROPOSALPOL = _descriptor.Descriptor(
  name='ProposalPOL',
  full_name='tendermint.consensus.ProposalPOL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.consensus.ProposalPOL.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposal_pol_round', full_name='tendermint.consensus.ProposalPOL.proposal_pol_round', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposal_pol', full_name='tendermint.consensus.ProposalPOL.proposal_pol', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=521,
  serialized_end=638,
)


_BLOCKPART = _descriptor.Descriptor(
  name='BlockPart',
  full_name='tendermint.consensus.BlockPart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.consensus.BlockPart.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='tendermint.consensus.BlockPart.round', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='part', full_name='tendermint.consensus.BlockPart.part', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=640,
  serialized_end=726,
)


_VOTE = _descriptor.Descriptor(
  name='Vote',
  full_name='tendermint.consensus.Vote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vote', full_name='tendermint.consensus.Vote.vote', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=728,
  serialized_end=772,
)


_HASVOTE = _descriptor.Descriptor(
  name='HasVote',
  full_name='tendermint.consensus.HasVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.consensus.HasVote.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='tendermint.consensus.HasVote.round', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='tendermint.consensus.HasVote.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='tendermint.consensus.HasVote.index', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=876,
)


_VOTESETMAJ23 = _descriptor.Descriptor(
  name='VoteSetMaj23',
  full_name='tendermint.consensus.VoteSetMaj23',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.consensus.VoteSetMaj23.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='tendermint.consensus.VoteSetMaj23.round', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='tendermint.consensus.VoteSetMaj23.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_id', full_name='tendermint.consensus.VoteSetMaj23.block_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\007BlockID\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=879,
  serialized_end=1033,
)


_VOTESETBITS = _descriptor.Descriptor(
  name='VoteSetBits',
  full_name='tendermint.consensus.VoteSetBits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.consensus.VoteSetBits.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='tendermint.consensus.VoteSetBits.round', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='tendermint.consensus.VoteSetBits.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_id', full_name='tendermint.consensus.VoteSetBits.block_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\007BlockID\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='votes', full_name='tendermint.consensus.VoteSetBits.votes', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1036,
  serialized_end=1242,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='tendermint.consensus.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_round_step', full_name='tendermint.consensus.Message.new_round_step', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_valid_block', full_name='tendermint.consensus.Message.new_valid_block', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposal', full_name='tendermint.consensus.Message.proposal', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposal_pol', full_name='tendermint.consensus.Message.proposal_pol', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_part', full_name='tendermint.consensus.Message.block_part', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vote', full_name='tendermint.consensus.Message.vote', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_vote', full_name='tendermint.consensus.Message.has_vote', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vote_set_maj23', full_name='tendermint.consensus.Message.vote_set_maj23', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vote_set_bits', full_name='tendermint.consensus.Message.vote_set_bits', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sum', full_name='tendermint.consensus.Message.sum',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1245,
  serialized_end=1770,
)

_NEWVALIDBLOCK.fields_by_name['block_part_set_header'].message_type = tendermint_dot_types_dot_types__pb2._PARTSETHEADER
_NEWVALIDBLOCK.fields_by_name['block_parts'].message_type = tendermint_dot_libs_dot_bits_dot_types__pb2._BITARRAY
_PROPOSAL.fields_by_name['proposal'].message_type = tendermint_dot_types_dot_types__pb2._PROPOSAL
_PROPOSALPOL.fields_by_name['proposal_pol'].message_type = tendermint_dot_libs_dot_bits_dot_types__pb2._BITARRAY
_BLOCKPART.fields_by_name['part'].message_type = tendermint_dot_types_dot_types__pb2._PART
_VOTE.fields_by_name['vote'].message_type = tendermint_dot_types_dot_types__pb2._VOTE
_HASVOTE.fields_by_name['type'].enum_type = tendermint_dot_types_dot_types__pb2._SIGNEDMSGTYPE
_VOTESETMAJ23.fields_by_name['type'].enum_type = tendermint_dot_types_dot_types__pb2._SIGNEDMSGTYPE
_VOTESETMAJ23.fields_by_name['block_id'].message_type = tendermint_dot_types_dot_types__pb2._BLOCKID
_VOTESETBITS.fields_by_name['type'].enum_type = tendermint_dot_types_dot_types__pb2._SIGNEDMSGTYPE
_VOTESETBITS.fields_by_name['block_id'].message_type = tendermint_dot_types_dot_types__pb2._BLOCKID
_VOTESETBITS.fields_by_name['votes'].message_type = tendermint_dot_libs_dot_bits_dot_types__pb2._BITARRAY
_MESSAGE.fields_by_name['new_round_step'].message_type = _NEWROUNDSTEP
_MESSAGE.fields_by_name['new_valid_block'].message_type = _NEWVALIDBLOCK
_MESSAGE.fields_by_name['proposal'].message_type = _PROPOSAL
_MESSAGE.fields_by_name['proposal_pol'].message_type = _PROPOSALPOL
_MESSAGE.fields_by_name['block_part'].message_type = _BLOCKPART
_MESSAGE.fields_by_name['vote'].message_type = _VOTE
_MESSAGE.fields_by_name['has_vote'].message_type = _HASVOTE
_MESSAGE.fields_by_name['vote_set_maj23'].message_type = _VOTESETMAJ23
_MESSAGE.fields_by_name['vote_set_bits'].message_type = _VOTESETBITS
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['new_round_step'])
_MESSAGE.fields_by_name['new_round_step'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['new_valid_block'])
_MESSAGE.fields_by_name['new_valid_block'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['proposal'])
_MESSAGE.fields_by_name['proposal'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['proposal_pol'])
_MESSAGE.fields_by_name['proposal_pol'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['block_part'])
_MESSAGE.fields_by_name['block_part'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['vote'])
_MESSAGE.fields_by_name['vote'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['has_vote'])
_MESSAGE.fields_by_name['has_vote'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['vote_set_maj23'])
_MESSAGE.fields_by_name['vote_set_maj23'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['vote_set_bits'])
_MESSAGE.fields_by_name['vote_set_bits'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
DESCRIPTOR.message_types_by_name['NewRoundStep'] = _NEWROUNDSTEP
DESCRIPTOR.message_types_by_name['NewValidBlock'] = _NEWVALIDBLOCK
DESCRIPTOR.message_types_by_name['Proposal'] = _PROPOSAL
DESCRIPTOR.message_types_by_name['ProposalPOL'] = _PROPOSALPOL
DESCRIPTOR.message_types_by_name['BlockPart'] = _BLOCKPART
DESCRIPTOR.message_types_by_name['Vote'] = _VOTE
DESCRIPTOR.message_types_by_name['HasVote'] = _HASVOTE
DESCRIPTOR.message_types_by_name['VoteSetMaj23'] = _VOTESETMAJ23
DESCRIPTOR.message_types_by_name['VoteSetBits'] = _VOTESETBITS
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NewRoundStep = _reflection.GeneratedProtocolMessageType('NewRoundStep', (_message.Message,), {
  'DESCRIPTOR' : _NEWROUNDSTEP,
  '__module__' : 'tendermint.consensus.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.consensus.NewRoundStep)
  })
_sym_db.RegisterMessage(NewRoundStep)

NewValidBlock = _reflection.GeneratedProtocolMessageType('NewValidBlock', (_message.Message,), {
  'DESCRIPTOR' : _NEWVALIDBLOCK,
  '__module__' : 'tendermint.consensus.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.consensus.NewValidBlock)
  })
_sym_db.RegisterMessage(NewValidBlock)

Proposal = _reflection.GeneratedProtocolMessageType('Proposal', (_message.Message,), {
  'DESCRIPTOR' : _PROPOSAL,
  '__module__' : 'tendermint.consensus.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.consensus.Proposal)
  })
_sym_db.RegisterMessage(Proposal)

ProposalPOL = _reflection.GeneratedProtocolMessageType('ProposalPOL', (_message.Message,), {
  'DESCRIPTOR' : _PROPOSALPOL,
  '__module__' : 'tendermint.consensus.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.consensus.ProposalPOL)
  })
_sym_db.RegisterMessage(ProposalPOL)

BlockPart = _reflection.GeneratedProtocolMessageType('BlockPart', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKPART,
  '__module__' : 'tendermint.consensus.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.consensus.BlockPart)
  })
_sym_db.RegisterMessage(BlockPart)

Vote = _reflection.GeneratedProtocolMessageType('Vote', (_message.Message,), {
  'DESCRIPTOR' : _VOTE,
  '__module__' : 'tendermint.consensus.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.consensus.Vote)
  })
_sym_db.RegisterMessage(Vote)

HasVote = _reflection.GeneratedProtocolMessageType('HasVote', (_message.Message,), {
  'DESCRIPTOR' : _HASVOTE,
  '__module__' : 'tendermint.consensus.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.consensus.HasVote)
  })
_sym_db.RegisterMessage(HasVote)

VoteSetMaj23 = _reflection.GeneratedProtocolMessageType('VoteSetMaj23', (_message.Message,), {
  'DESCRIPTOR' : _VOTESETMAJ23,
  '__module__' : 'tendermint.consensus.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.consensus.VoteSetMaj23)
  })
_sym_db.RegisterMessage(VoteSetMaj23)

VoteSetBits = _reflection.GeneratedProtocolMessageType('VoteSetBits', (_message.Message,), {
  'DESCRIPTOR' : _VOTESETBITS,
  '__module__' : 'tendermint.consensus.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.consensus.VoteSetBits)
  })
_sym_db.RegisterMessage(VoteSetBits)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'tendermint.consensus.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.consensus.Message)
  })
_sym_db.RegisterMessage(Message)


DESCRIPTOR._options = None
_NEWVALIDBLOCK.fields_by_name['block_part_set_header']._options = None
_PROPOSAL.fields_by_name['proposal']._options = None
_PROPOSALPOL.fields_by_name['proposal_pol']._options = None
_BLOCKPART.fields_by_name['part']._options = None
_VOTESETMAJ23.fields_by_name['block_id']._options = None
_VOTESETBITS.fields_by_name['block_id']._options = None
_VOTESETBITS.fields_by_name['votes']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/attestation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/peggy/v1/attestation.proto',
  package='injective.peggy.v1',
  syntax='proto3',
  serialized_options=b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$injective/peggy/v1/attestation.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"c\n\x0b\x41ttestation\x12\x10\n\x08observed\x18\x01 \x01(\x08\x12\r\n\x05votes\x18\x02 \x03(\t\x12\x0e\n\x06height\x18\x03 \x01(\x04\x12#\n\x05\x63laim\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"^\n\nERC20Token\x12\x10\n\x08\x63ontract\x18\x01 \x01(\t\x12>\n\x06\x61mount\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00*\x9f\x02\n\tClaimType\x12.\n\x12\x43LAIM_TYPE_UNKNOWN\x10\x00\x1a\x16\x8a\x9d \x12\x43LAIM_TYPE_UNKNOWN\x12.\n\x12\x43LAIM_TYPE_DEPOSIT\x10\x01\x1a\x16\x8a\x9d \x12\x43LAIM_TYPE_DEPOSIT\x12\x30\n\x13\x43LAIM_TYPE_WITHDRAW\x10\x02\x1a\x17\x8a\x9d \x13\x43LAIM_TYPE_WITHDRAW\x12<\n\x19\x43LAIM_TYPE_ERC20_DEPLOYED\x10\x03\x1a\x1d\x8a\x9d \x19\x43LAIM_TYPE_ERC20_DEPLOYED\x12<\n\x19\x43LAIM_TYPE_VALSET_UPDATED\x10\x04\x1a\x1d\x8a\x9d \x19\x43LAIM_TYPE_VALSET_UPDATED\x1a\x04\x88\xa3\x1e\x00\x42MZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])

_CLAIMTYPE = _descriptor.EnumDescriptor(
  name='ClaimType',
  full_name='injective.peggy.v1.ClaimType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLAIM_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=b'\212\235 \022CLAIM_TYPE_UNKNOWN',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLAIM_TYPE_DEPOSIT', index=1, number=1,
      serialized_options=b'\212\235 \022CLAIM_TYPE_DEPOSIT',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLAIM_TYPE_WITHDRAW', index=2, number=2,
      serialized_options=b'\212\235 \023CLAIM_TYPE_WITHDRAW',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLAIM_TYPE_ERC20_DEPLOYED', index=3, number=3,
      serialized_options=b'\212\235 \031CLAIM_TYPE_ERC20_DEPLOYED',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLAIM_TYPE_VALSET_UPDATED', index=4, number=4,
      serialized_options=b'\212\235 \031CLAIM_TYPE_VALSET_UPDATED',
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=b'\210\243\036\000',
  serialized_start=307,
  serialized_end=594,
)
_sym_db.RegisterEnumDescriptor(_CLAIMTYPE)

ClaimType = enum_type_wrapper.EnumTypeWrapper(_CLAIMTYPE)
CLAIM_TYPE_UNKNOWN = 0
CLAIM_TYPE_DEPOSIT = 1
CLAIM_TYPE_WITHDRAW = 2
CLAIM_TYPE_ERC20_DEPLOYED = 3
CLAIM_TYPE_VALSET_UPDATED = 4



_ATTESTATION = _descriptor.Descriptor(
  name='Attestation',
  full_name='injective.peggy.v1.Attestation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='observed', full_name='injective.peggy.v1.Attestation.observed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='votes', full_name='injective.peggy.v1.Attestation.votes', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='injective.peggy.v1.Attestation.height', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='claim', full_name='injective.peggy.v1.Attestation.claim', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=208,
)


_ERC20TOKEN = _descriptor.Descriptor(
  name='ERC20Token',
  full_name='injective.peggy.v1.ERC20Token',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contract', full_name='injective.peggy.v1.ERC20Token.contract', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.peggy.v1.ERC20Token.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=304,
)

_ATTESTATION.fields_by_name['claim'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['Attestation'] = _ATTESTATION
DESCRIPTOR.message_types_by_name['ERC20Token'] = _ERC20TOKEN
DESCRIPTOR.enum_types_by_name['ClaimType'] = _CLAIMTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Attestation = _reflection.GeneratedProtocolMessageType('Attestation', (_message.Message,), {
  'DESCRIPTOR' : _ATTESTATION,
  '__module__' : 'injective.peggy.v1.attestation_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.Attestation)
  })
_sym_db.RegisterMessage(Attestation)

ERC20Token = _reflection.GeneratedProtocolMessageType('ERC20Token', (_message.Message,), {
  'DESCRIPTOR' : _ERC20TOKEN,
  '__module__' : 'injective.peggy.v1.attestation_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.ERC20Token)
  })
_sym_db.RegisterMessage(ERC20Token)


DESCRIPTOR._options = None
_CLAIMTYPE._options = None
_CLAIMTYPE.values_by_name["CLAIM_TYPE_UNKNOWN"]._options = None
_CLAIMTYPE.values_by_name["CLAIM_TYPE_DEPOSIT"]._options = None
_CLAIMTYPE.values_by_name["CLAIM_TYPE_WITHDRAW"]._options = None
_CLAIMTYPE.values_by_name["CLAIM_TYPE_ERC20_DEPLOYED"]._options = None
_CLAIMTYPE.values_by_name["CLAIM_TYPE_VALSET_UPDATED"]._options = None
_ERC20TOKEN.fields_by_name['amount']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/rpc/grpc/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.abci import types_pb2 as tendermint_dot_abci_dot_types__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/rpc/grpc/types.proto',
  package='tendermint.rpc.grpc',
  syntax='proto3',
  serialized_options=b'Z2github.com/tendermint/tendermint/rpc/grpc;coregrpc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1ftendermint/rpc/grpc/types.proto\x12\x13tendermint.rpc.grpc\x1a\x1btendermint/abci/types.proto\"\r\n\x0bRequestPing\" \n\x12RequestBroadcastTx\x12\n\n\x02tx\x18\x01 \x01(\x0c\"\x0e\n\x0cResponsePing\"\x81\x01\n\x13ResponseBroadcastTx\x12\x32\n\x08\x63heck_tx\x18\x01 \x01(\x0b\x32 .tendermint.abci.ResponseCheckTx\x12\x36\n\ndeliver_tx\x18\x02 \x01(\x0b\x32\".tendermint.abci.ResponseDeliverTx2\xbd\x01\n\x0c\x42roadcastAPI\x12K\n\x04Ping\x12 .tendermint.rpc.grpc.RequestPing\x1a!.tendermint.rpc.grpc.ResponsePing\x12`\n\x0b\x42roadcastTx\x12\'.tendermint.rpc.grpc.RequestBroadcastTx\x1a(.tendermint.rpc.grpc.ResponseBroadcastTxB4Z2github.com/tendermint/tendermint/rpc/grpc;coregrpcb\x06proto3'
  ,
  dependencies=[tendermint_dot_abci_dot_types__pb2.DESCRIPTOR,])




_REQUESTPING = _descriptor.Descriptor(
  name='RequestPing',
  full_name='tendermint.rpc.grpc.RequestPing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=98,
)


_REQUESTBROADCASTTX = _descriptor.Descriptor(
  name='RequestBroadcastTx',
  full_name='tendermint.rpc.grpc.RequestBroadcastTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx', full_name='tendermint.rpc.grpc.RequestBroadcastTx.tx', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=132,
)


_RESPONSEPING = _descriptor.Descriptor(
  name='ResponsePing',
  full_name='tendermint.rpc.grpc.ResponsePing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=148,
)


_RESPONSEBROADCASTTX = _descriptor.Descriptor(
  name='ResponseBroadcastTx',
  full_name='tendermint.rpc.grpc.ResponseBroadcastTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='check_tx', full_name='tendermint.rpc.grpc.ResponseBroadcastTx.check_tx', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deliver_tx', full_name='tendermint.rpc.grpc.ResponseBroadcastTx.deliver_tx', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=280,
)

_RESPONSEBROADCASTTX.fields_by_name['check_tx'].message_type = tendermint_dot_abci_dot_types__pb2._RESPONSECHECKTX
_RESPONSEBROADCASTTX.fields_by_name['deliver_tx'].message_type = tendermint_dot_abci_dot_types__pb2._RESPONSEDELIVERTX
DESCRIPTOR.message_types_by_name['RequestPing'] = _REQUESTPING
DESCRIPTOR.message_types_by_name['RequestBroadcastTx'] = _REQUESTBROADCASTTX
DESCRIPTOR.message_types_by_name['ResponsePing'] = _RESPONSEPING
DESCRIPTOR.message_types_by_name['ResponseBroadcastTx'] = _RESPONSEBROADCASTTX
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestPing = _reflection.GeneratedProtocolMessageType('RequestPing', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTPING,
  '__module__' : 'tendermint.rpc.grpc.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.rpc.grpc.RequestPing)
  })
_sym_db.RegisterMessage(RequestPing)

RequestBroadcastTx = _reflection.GeneratedProtocolMessageType('RequestBroadcastTx', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTBROADCASTTX,
  '__module__' : 'tendermint.rpc.grpc.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.rpc.grpc.RequestBroadcastTx)
  })
_sym_db.RegisterMessage(RequestBroadcastTx)

ResponsePing = _reflection.GeneratedProtocolMessageType('ResponsePing', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEPING,
  '__module__' : 'tendermint.rpc.grpc.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.rpc.grpc.ResponsePing)
  })
_sym_db.RegisterMessage(ResponsePing)

ResponseBroadcastTx = _reflection.GeneratedProtocolMessageType('ResponseBroadcastTx', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEBROADCASTTX,
  '__module__' : 'tendermint.rpc.grpc.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.rpc.grpc.ResponseBroadcastTx)
  })
_sym_db.RegisterMessage(ResponseBroadcastTx)


DESCRIPTOR._options = None

_BROADCASTAPI = _descriptor.ServiceDescriptor(
  name='BroadcastAPI',
  full_name='tendermint.rpc.grpc.BroadcastAPI',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=283,
  serialized_end=472,
  methods=[
  _descriptor.MethodDescriptor(
    name='Ping',
    full_name='tendermint.rpc.grpc.BroadcastAPI.Ping',
    index=0,
    containing_service=None,
    input_type=_REQUESTPING,
    output_type=_RESPONSEPING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BroadcastTx',
    full_name='tendermint.rpc.grpc.BroadcastAPI.BroadcastTx',
    index=1,
    containing_service=None,
    input_type=_REQUESTBROADCASTTX,
    output_type=_RESPONSEBROADCASTTX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BROADCASTAPI)

DESCRIPTOR.services_by_name['BroadcastAPI'] = _BROADCASTAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/feegrant/v1beta1/feegrant.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/feegrant/v1beta1/feegrant.proto',
  package='cosmos.feegrant.v1beta1',
  syntax='proto3',
  serialized_options=b'Z\'github.com/cosmos/cosmos-sdk/x/feegrant',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&cosmos/feegrant/v1beta1/feegrant.proto\x12\x17\x63osmos.feegrant.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xbb\x01\n\x0e\x42\x61sicAllowance\x12`\n\x0bspend_limit\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x34\n\nexpiration\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01:\x11\xd2\xb4-\rFeeAllowanceI\"\xa5\x03\n\x11PeriodicAllowance\x12<\n\x05\x62\x61sic\x18\x01 \x01(\x0b\x32\'.cosmos.feegrant.v1beta1.BasicAllowanceB\x04\xc8\xde\x1f\x00\x12\x33\n\x06period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\x98\xdf\x1f\x01\xc8\xde\x1f\x00\x12g\n\x12period_spend_limit\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x65\n\x10period_can_spend\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12:\n\x0cperiod_reset\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00:\x11\xd2\xb4-\rFeeAllowanceI\"\x82\x01\n\x13\x41llowedMsgAllowance\x12:\n\tallowance\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x11\xca\xb4-\rFeeAllowanceI\x12\x18\n\x10\x61llowed_messages\x18\x02 \x03(\t:\x15\x88\xa0\x1f\x00\xd2\xb4-\rFeeAllowanceI\"e\n\x05Grant\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12:\n\tallowance\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x11\xca\xb4-\rFeeAllowanceIB)Z\'github.com/cosmos/cosmos-sdk/x/feegrantb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,cosmos__proto_dot_cosmos__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])




_BASICALLOWANCE = _descriptor.Descriptor(
  name='BasicAllowance',
  full_name='cosmos.feegrant.v1beta1.BasicAllowance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spend_limit', full_name='cosmos.feegrant.v1beta1.BasicAllowance.spend_limit', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='cosmos.feegrant.v1beta1.BasicAllowance.expiration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\337\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rFeeAllowanceI',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=428,
)


_PERIODICALLOWANCE = _descriptor.Descriptor(
  name='PeriodicAllowance',
  full_name='cosmos.feegrant.v1beta1.PeriodicAllowance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='basic', full_name='cosmos.feegrant.v1beta1.PeriodicAllowance.basic', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='period', full_name='cosmos.feegrant.v1beta1.PeriodicAllowance.period', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\230\337\037\001\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='period_spend_limit', full_name='cosmos.feegrant.v1beta1.PeriodicAllowance.period_spend_limit', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='period_can_spend', full_name='cosmos.feegrant.v1beta1.PeriodicAllowance.period_can_spend', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='period_reset', full_name='cosmos.feegrant.v1beta1.PeriodicAllowance.period_reset', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\337\037\001\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rFeeAllowanceI',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=431,
  serialized_end=852,
)


_ALLOWEDMSGALLOWANCE = _descriptor.Descriptor(
  name='AllowedMsgAllowance',
  full_name='cosmos.feegrant.v1beta1.AllowedMsgAllowance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allowance', full_name='cosmos.feegrant.v1beta1.AllowedMsgAllowance.allowance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\264-\rFeeAllowanceI', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_messages', full_name='cosmos.feegrant.v1beta1.AllowedMsgAllowance.allowed_messages', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000\322\264-\rFeeAllowanceI',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=985,
)


_GRANT = _descriptor.Descriptor(
  name='Grant',
  full_name='cosmos.feegrant.v1beta1.Grant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='granter', full_name='cosmos.feegrant.v1beta1.Grant.granter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grantee', full_name='cosmos.feegrant.v1beta1.Grant.grantee', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowance', full_name='cosmos.feegrant.v1beta1.Grant.allowance', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\264-\rFeeAllowanceI', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=987,
  serialized_end=1088,
)

_BASICALLOWANCE.fields_by_name['spend_limit'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_BASICALLOWANCE.fields_by_name['expiration'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PERIODICALLOWANCE.fields_by_name['basic'].message_type = _BASICALLOWANCE
_PERIODICALLOWANCE.fields_by_name['period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_PERIODICALLOWANCE.fields_by_name['period_spend_limit'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_PERIODICALLOWANCE.fields_by_name['period_can_spend'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_PERIODICALLOWANCE.fields_by_name['period_reset'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ALLOWEDMSGALLOWANCE.fields_by_name['allowance'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_GRANT.fields_by_name['allowance'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['BasicAllowance'] = _BASICALLOWANCE
DESCRIPTOR.message_types_by_name['PeriodicAllowance'] = _PERIODICALLOWANCE
DESCRIPTOR.message_types_by_name['AllowedMsgAllowance'] = _ALLOWEDMSGALLOWANCE
DESCRIPTOR.message_types_by_name['Grant'] = _GRANT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BasicAllowance = _reflection.GeneratedProtocolMessageType('BasicAllowance', (_message.Message,), {
  'DESCRIPTOR' : _BASICALLOWANCE,
  '__module__' : 'cosmos.feegrant.v1beta1.feegrant_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.BasicAllowance)
  })
_sym_db.RegisterMessage(BasicAllowance)

PeriodicAllowance = _reflection.GeneratedProtocolMessageType('PeriodicAllowance', (_message.Message,), {
  'DESCRIPTOR' : _PERIODICALLOWANCE,
  '__module__' : 'cosmos.feegrant.v1beta1.feegrant_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.PeriodicAllowance)
  })
_sym_db.RegisterMessage(PeriodicAllowance)

AllowedMsgAllowance = _reflection.GeneratedProtocolMessageType('AllowedMsgAllowance', (_message.Message,), {
  'DESCRIPTOR' : _ALLOWEDMSGALLOWANCE,
  '__module__' : 'cosmos.feegrant.v1beta1.feegrant_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.AllowedMsgAllowance)
  })
_sym_db.RegisterMessage(AllowedMsgAllowance)

Grant = _reflection.GeneratedProtocolMessageType('Grant', (_message.Message,), {
  'DESCRIPTOR' : _GRANT,
  '__module__' : 'cosmos.feegrant.v1beta1.feegrant_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.Grant)
  })
_sym_db.RegisterMessage(Grant)


DESCRIPTOR._options = None
_BASICALLOWANCE.fields_by_name['spend_limit']._options = None
_BASICALLOWANCE.fields_by_name['expiration']._options = None
_BASICALLOWANCE._options = None
_PERIODICALLOWANCE.fields_by_name['basic']._options = None
_PERIODICALLOWANCE.fields_by_name['period']._options = None
_PERIODICALLOWANCE.fields_by_name['period_spend_limit']._options = None
_PERIODICALLOWANCE.fields_by_name['period_can_spend']._options = None
_PERIODICALLOWANCE.fields_by_name['period_reset']._options = None
_PERIODICALLOWANCE._options = None
_ALLOWEDMSGALLOWANCE.fields_by_name['allowance']._options = None
_ALLOWEDMSGALLOWANCE._options = None
_GRANT.fields_by_name['allowance']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/connection/v1/connection.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.core.commitment.v1 import commitment_pb2 as ibc_dot_core_dot_commitment_dot_v1_dot_commitment__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ibc/core/connection/v1/connection.proto',
  package='ibc.core.connection.v1',
  syntax='proto3',
  serialized_options=b'Z<github.com/cosmos/ibc-go/v2/modules/core/03-connection/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'ibc/core/connection/v1/connection.proto\x12\x16ibc.core.connection.v1\x1a\x14gogoproto/gogo.proto\x1a\'ibc/core/commitment/v1/commitment.proto\"\x90\x02\n\rConnectionEnd\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12\x31\n\x08versions\x18\x02 \x03(\x0b\x32\x1f.ibc.core.connection.v1.Version\x12,\n\x05state\x18\x03 \x01(\x0e\x32\x1d.ibc.core.connection.v1.State\x12@\n\x0c\x63ounterparty\x18\x04 \x01(\x0b\x32$.ibc.core.connection.v1.CounterpartyB\x04\xc8\xde\x1f\x00\x12-\n\x0c\x64\x65lay_period\x18\x05 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"delay_period\":\x04\x88\xa0\x1f\x00\"\xb2\x02\n\x14IdentifiedConnection\x12\x19\n\x02id\x18\x01 \x01(\tB\r\xf2\xde\x1f\tyaml:\"id\"\x12\'\n\tclient_id\x18\x02 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12\x31\n\x08versions\x18\x03 \x03(\x0b\x32\x1f.ibc.core.connection.v1.Version\x12,\n\x05state\x18\x04 \x01(\x0e\x32\x1d.ibc.core.connection.v1.State\x12@\n\x0c\x63ounterparty\x18\x05 \x01(\x0b\x32$.ibc.core.connection.v1.CounterpartyB\x04\xc8\xde\x1f\x00\x12-\n\x0c\x64\x65lay_period\x18\x06 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"delay_period\":\x04\x88\xa0\x1f\x00\"\xaa\x01\n\x0c\x43ounterparty\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12/\n\rconnection_id\x18\x02 \x01(\tB\x18\xf2\xde\x1f\x14yaml:\"connection_id\"\x12:\n\x06prefix\x18\x03 \x01(\x0b\x32$.ibc.core.commitment.v1.MerklePrefixB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"\x1c\n\x0b\x43lientPaths\x12\r\n\x05paths\x18\x01 \x03(\t\"I\n\x0f\x43onnectionPaths\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12\r\n\x05paths\x18\x02 \x03(\t\"5\n\x07Version\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x10\n\x08\x66\x65\x61tures\x18\x02 \x03(\t:\x04\x88\xa0\x1f\x00\"U\n\x06Params\x12K\n\x1bmax_expected_time_per_block\x18\x01 \x01(\x04\x42&\xf2\xde\x1f\"yaml:\"max_expected_time_per_block\"*\x99\x01\n\x05State\x12\x36\n\x1fSTATE_UNINITIALIZED_UNSPECIFIED\x10\x00\x1a\x11\x8a\x9d \rUNINITIALIZED\x12\x18\n\nSTATE_INIT\x10\x01\x1a\x08\x8a\x9d \x04INIT\x12\x1e\n\rSTATE_TRYOPEN\x10\x02\x1a\x0b\x8a\x9d \x07TRYOPEN\x12\x18\n\nSTATE_OPEN\x10\x03\x1a\x08\x8a\x9d \x04OPEN\x1a\x04\x88\xa3\x1e\x00\x42>Z<github.com/cosmos/ibc-go/v2/modules/core/03-connection/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,ibc_dot_core_dot_commitment_dot_v1_dot_commitment__pb2.DESCRIPTOR,])

_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='ibc.core.connection.v1.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNINITIALIZED_UNSPECIFIED', index=0, number=0,
      serialized_options=b'\212\235 \rUNINITIALIZED',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_INIT', index=1, number=1,
      serialized_options=b'\212\235 \004INIT',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_TRYOPEN', index=2, number=2,
      serialized_options=b'\212\235 \007TRYOPEN',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_OPEN', index=3, number=3,
      serialized_options=b'\212\235 \004OPEN',
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=b'\210\243\036\000',
  serialized_start=1135,
  serialized_end=1288,
)
_sym_db.RegisterEnumDescriptor(_STATE)

State = enum_type_wrapper.EnumTypeWrapper(_STATE)
STATE_UNINITIALIZED_UNSPECIFIED = 0
STATE_INIT = 1
STATE_TRYOPEN = 2
STATE_OPEN = 3



_CONNECTIONEND = _descriptor.Descriptor(
  name='ConnectionEnd',
  full_name='ibc.core.connection.v1.ConnectionEnd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='ibc.core.connection.v1.ConnectionEnd.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"client_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='versions', full_name='ibc.core.connection.v1.ConnectionEnd.versions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='ibc.core.connection.v1.ConnectionEnd.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counterparty', full_name='ibc.core.connection.v1.ConnectionEnd.counterparty', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay_period', full_name='ibc.core.connection.v1.ConnectionEnd.delay_period', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"delay_period\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=403,
)


_IDENTIFIEDCONNECTION = _descriptor.Descriptor(
  name='IdentifiedConnection',
  full_name='ibc.core.connection.v1.IdentifiedConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ibc.core.connection.v1.IdentifiedConnection.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\tyaml:\"id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='ibc.core.connection.v1.IdentifiedConnection.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"client_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='versions', full_name='ibc.core.connection.v1.IdentifiedConnection.versions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='ibc.core.connection.v1.IdentifiedConnection.state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counterparty', full_name='ibc.core.connection.v1.IdentifiedConnection.counterparty', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay_period', full_name='ibc.core.connection.v1.IdentifiedConnection.delay_period', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"delay_period\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=406,
  serialized_end=712,
)


_COUNTERPARTY = _descriptor.Descriptor(
  name='Counterparty',
  full_name='ibc.core.connection.v1.Counterparty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='ibc.core.connection.v1.Counterparty.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"client_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='ibc.core.connection.v1.Counterparty.connection_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\024yaml:\"connection_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='ibc.core.connection.v1.Counterparty.prefix', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=715,
  serialized_end=885,
)


_CLIENTPATHS = _descriptor.Descriptor(
  name='ClientPaths',
  full_name='ibc.core.connection.v1.ClientPaths',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='paths', full_name='ibc.core.connection.v1.ClientPaths.paths', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=887,
  serialized_end=915,
)


_CONNECTIONPATHS = _descriptor.Descriptor(
  name='ConnectionPaths',
  full_name='ibc.core.connection.v1.ConnectionPaths',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='ibc.core.connection.v1.ConnectionPaths.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"client_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paths', full_name='ibc.core.connection.v1.ConnectionPaths.paths', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=917,
  serialized_end=990,
)


_VERSION = _descriptor.Descriptor(
  name='Version',
  full_name='ibc.core.connection.v1.Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='ibc.core.connection.v1.Version.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='ibc.core.connection.v1.Version.features', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=992,
  serialized_end=1045,
)


_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='ibc.core.connection.v1.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_expected_time_per_block', full_name='ibc.core.connection.v1.Params.max_expected_time_per_block', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\"yaml:\"max_expected_time_per_block\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1047,
  serialized_end=1132,
)

_CONNECTIONEND.fields_by_name['versions'].message_type = _VERSION
_CONNECTIONEND.fields_by_name['state'].enum_type = _STATE
_CONNECTIONEND.fields_by_name['counterparty'].message_type = _COUNTERPARTY
_IDENTIFIEDCONNECTION.fields_by_name['versions'].message_type = _VERSION
_IDENTIFIEDCONNECTION.fields_by_name['state'].enum_type = _STATE
_IDENTIFIEDCONNECTION.fields_by_name['counterparty'].message_type = _COUNTERPARTY
_COUNTERPARTY.fields_by_name['prefix'].message_type = ibc_dot_core_dot_commitment_dot_v1_dot_commitment__pb2._MERKLEPREFIX
DESCRIPTOR.message_types_by_name['ConnectionEnd'] = _CONNECTIONEND
DESCRIPTOR.message_types_by_name['IdentifiedConnection'] = _IDENTIFIEDCONNECTION
DESCRIPTOR.message_types_by_name['Counterparty'] = _COUNTERPARTY
DESCRIPTOR.message_types_by_name['ClientPaths'] = _CLIENTPATHS
DESCRIPTOR.message_types_by_name['ConnectionPaths'] = _CONNECTIONPATHS
DESCRIPTOR.message_types_by_name['Version'] = _VERSION
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.enum_types_by_name['State'] = _STATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConnectionEnd = _reflection.GeneratedProtocolMessageType('ConnectionEnd', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIONEND,
  '__module__' : 'ibc.core.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.connection.v1.ConnectionEnd)
  })
_sym_db.RegisterMessage(ConnectionEnd)

IdentifiedConnection = _reflection.GeneratedProtocolMessageType('IdentifiedConnection', (_message.Message,), {
  'DESCRIPTOR' : _IDENTIFIEDCONNECTION,
  '__module__' : 'ibc.core.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.connection.v1.IdentifiedConnection)
  })
_sym_db.RegisterMessage(IdentifiedConnection)

Counterparty = _reflection.GeneratedProtocolMessageType('Counterparty', (_message.Message,), {
  'DESCRIPTOR' : _COUNTERPARTY,
  '__module__' : 'ibc.core.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.connection.v1.Counterparty)
  })
_sym_db.RegisterMessage(Counterparty)

ClientPaths = _reflection.GeneratedProtocolMessageType('ClientPaths', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTPATHS,
  '__module__' : 'ibc.core.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.connection.v1.ClientPaths)
  })
_sym_db.RegisterMessage(ClientPaths)

ConnectionPaths = _reflection.GeneratedProtocolMessageType('ConnectionPaths', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIONPATHS,
  '__module__' : 'ibc.core.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.connection.v1.ConnectionPaths)
  })
_sym_db.RegisterMessage(ConnectionPaths)

Version = _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), {
  'DESCRIPTOR' : _VERSION,
  '__module__' : 'ibc.core.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.connection.v1.Version)
  })
_sym_db.RegisterMessage(Version)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'ibc.core.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.connection.v1.Params)
  })
_sym_db.RegisterMessage(Params)


DESCRIPTOR._options = None
_STATE._options = None
_STATE.values_by_name["STATE_UNINITIALIZED_UNSPECIFIED"]._options = None
_STATE.values_by_name["STATE_INIT"]._options = None
_STATE.values_by_name["STATE_TRYOPEN"]._options = None
_STATE.values_by_name["STATE_OPEN"]._options = None
_CONNECTIONEND.fields_by_name['client_id']._options = None
_CONNECTIONEND.fields_by_name['counterparty']._options = None
_CONNECTIONEND.fields_by_name['delay_period']._options = None
_CONNECTIONEND._options = None
_IDENTIFIEDCONNECTION.fields_by_name['id']._options = None
_IDENTIFIEDCONNECTION.fields_by_name['client_id']._options = None
_IDENTIFIEDCONNECTION.fields_by_name['counterparty']._options = None
_IDENTIFIEDCONNECTION.fields_by_name['delay_period']._options = None
_IDENTIFIEDCONNECTION._options = None
_COUNTERPARTY.fields_by_name['client_id']._options = None
_COUNTERPARTY.fields_by_name['connection_id']._options = None
_COUNTERPARTY.fields_by_name['prefix']._options = None
_COUNTERPARTY._options = None
_CONNECTIONPATHS.fields_by_name['client_id']._options = None
_VERSION._options = None
_PARAMS.fields_by_name['max_expected_time_per_block']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/wasmx/v1/tx.proto',
  package='injective.wasmx.v1',
  syntax='proto3',
  serialized_options=b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1binjective/wasmx/v1/tx.proto\x12\x12injective.wasmx.v12\x05\n\x03MsgBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/typesb\x06proto3'
)



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_MSG = _descriptor.ServiceDescriptor(
  name='Msg',
  full_name='injective.wasmx.v1.Msg',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=51,
  serialized_end=56,
  methods=[
])
_sym_db.RegisterServiceDescriptor(_MSG)

DESCRIPTOR.services_by_name['Msg'] = _MSG

# @@protoc_insertion_point(module_scope)
